@@ -44,6 +44,8 @@ from ZPublisher.Converters import get_converter
 from ZPublisher.interfaces import IXmlrpcChecker
 from ZPublisher.utils import basic_auth_decode
 
+from .cookie import getCookieValuePolicy
+
 
 # This may get overwritten during configuration
 default_encoding = 'utf-8'
@@ -1497,7 +1499,7 @@ class HTTPRequest(BaseRequest):
         return result + "</table>"
 
     def __repr__(self):
-        return "<{}, URL={}>".format(self.__class__.__name__, self.get('URL'))
+        return f"<{self.__class__.__name__}, URL={self.get('URL')}>"
 
     def text(self):
         result = "FORM\n\n"
@@ -1742,7 +1744,7 @@ def parse_cookie(text,
                 return result
 
     if name not in result:
-        result[name] = unquote(value)
+        result[name] = getCookieValuePolicy().load(name, value)
 
     return parse_cookie(text[c_len:], result)
 
@@ -1781,8 +1783,8 @@ class record:
     def __repr__(self):
         # return repr( self.__dict__ )
         return '{%s}' % ', '.join(
-            "'{}': {!r}".format(*item) for item in
-            sorted(self.__dict__.items()))
+            f"'{key}': {value!r}"
+            for key, value in sorted(self.__dict__.items()))
 
     def __eq__(self, other):
         if not isinstance(other, record):
