@@ -233,17 +233,26 @@ class HTTPBaseResponse(BaseResponse):
             location = location.decode(self.charset)
 
         # To be entirely correct, we must make sure that all non-ASCII
-        # characters in the path part are quoted correctly. This is required
-        # as we now allow non-ASCII IDs
+        # characters are quoted correctly.
         parsed = list(urlparse(location))
-
-        # Make a hacky guess whether the path component is already
-        # URL-encoded by checking for %. If it is, we don't touch it.
-        if '%' not in parsed[2]:
-            # The list of "safe" characters is from RFC 2396 section 2.3
-            # (unreserved characters that should not be escaped) plus
-            # section 3.3 (reserved characters in path components)
-            parsed[2] = quote(parsed[2], safe="/@!*'~();,=+$")
+        rfc2396_unreserved = "-_.!~*'()"  # RFC 2396 section 2.3
+        for idx, idx_safe in (
+                # authority
+                (1, ";:@?/&=+$,"),  # RFC 2396 section 3.2, 3.2.1, 3.2.3
+                # path
+                (2, "/;:@&=+$,"),  # RFC 2396 section 3.3
+                # params - actually part of path; empty in Python 3
+                (3, "/;:@&=+$,"),  # RFC 2396 section 3.3
+                # query
+                (4, ";/?:@&=+,$"),  # RFC 2396 section 3.4
+                # fragment
+                (5, ";/?:@&=+$,"),  # RFC 2396 section 4
+        ):
+            # Make a hacky guess whether the component is already
+            # URL-encoded by checking for %. If it is, we don't touch it.
+            if '%' not in parsed[idx]:
+                parsed[idx] = quote(parsed[idx],
+                                    safe=rfc2396_unreserved + idx_safe)
         location = urlunparse(parsed)
 
         self.setStatus(status, lock=lock)
@@ -309,11 +318,7 @@ class HTTPBaseResponse(BaseResponse):
         `value` may be text or bytes. The default encoding of respective python
         version is used.
         """
-        cookies = self.cookies
-        if name in cookies:
-            cookie = cookies[name]
-        else:
-            cookie = cookies[name] = {}
+        cookie = {}
         for k, v in kw.items():
             k, v = convertCookieParameter(k, v)
             cookie[k] = v
@@ -322,6 +327,13 @@ class HTTPBaseResponse(BaseResponse):
         # cookie['quoted'] = quoted
         getCookieParamPolicy().check_consistency(name, cookie)
 
+        # update ``self.cookies`` only if there have been no exceptions
+        cookies = self.cookies
+        if name in cookies:
+            cookies[name].update(cookie)
+        else:
+            cookies[name] = cookie
+
     def appendCookie(self, name, value):
         """ Set an HTTP cookie.
 
@@ -720,7 +732,10 @@ class HTTPBaseResponse(BaseResponse):
     def _unauthorized(self):
         realm = self.realm
         if realm:
-            self.setHeader('WWW-Authenticate', 'basic realm="%s"' % realm, 1)
+            self.setHeader(
+                'WWW-Authenticate',
+                'basic realm="%s", charset="UTF-8"' % realm,
+                1)
 
     @staticmethod
     def _html(title, body):
