@@ -182,29 +182,26 @@ class HTTPResponseTests(unittest.TestCase):
         response = self._makeOne()
         response.setCookie('foo', 'bar')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 2)
+        self.assertEqual(len(cookie), 1)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('quoted'), True)
 
     def test_setCookie_w_existing(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar')
         response.setCookie('foo', 'baz')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 2)
+        self.assertEqual(len(cookie), 1)
         self.assertEqual(cookie.get('value'), 'baz')
-        self.assertEqual(cookie.get('quoted'), True)
 
     def test_setCookie_no_attrs(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 2)
+        self.assertEqual(len(cookie), 1)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('quoted'), True)
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
-        self.assertEqual(cookies[0], ('Set-Cookie', 'foo="bar"'))
+        self.assertEqual(cookies[0], ('Set-Cookie', 'foo=bar'))
 
     def test_setCookie_w_expires(self):
         EXPIRES = 'Wed, 31 Dec 1997 23:59:59 GMT'
@@ -213,127 +210,117 @@ class HTTPResponseTests(unittest.TestCase):
         cookie = response.cookies.get('foo', None)
         self.assertTrue(cookie)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('expires'), EXPIRES)
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertEqual(cookie.get('Expires'), EXPIRES)
 
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
         self.assertEqual(cookies[0],
-                         ('Set-Cookie', 'foo="bar"; Expires=%s' % EXPIRES))
+                         ('Set-Cookie', 'foo=bar; Expires=%s' % EXPIRES))
 
     def test_setCookie_w_domain(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', domain='example.com')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('domain'), 'example.com')
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertEqual(cookie.get('Domain'), 'example.com')
 
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
         self.assertEqual(cookies[0],
-                         ('Set-Cookie', 'foo="bar"; Domain=example.com'))
+                         ('Set-Cookie', 'foo=bar; Domain=example.com'))
 
     def test_setCookie_w_path(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', path='/')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('path'), '/')
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertEqual(cookie.get('Path'), '/')
 
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
-        self.assertEqual(cookies[0], ('Set-Cookie', 'foo="bar"; Path=/'))
+        self.assertEqual(cookies[0], ('Set-Cookie', 'foo=bar; Path=/'))
 
     def test_setCookie_w_comment(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', comment='COMMENT')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('comment'), 'COMMENT')
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertEqual(cookie.get('Comment'), 'COMMENT')
 
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
         self.assertEqual(cookies[0],
-                         ('Set-Cookie', 'foo="bar"; Comment=COMMENT'))
+                         ('Set-Cookie', 'foo=bar; Comment=COMMENT'))
 
     def test_setCookie_w_secure_true_value(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', secure='SECURE')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('secure'), 'SECURE')
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertIs(cookie.get('Secure'), True)
 
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
-        self.assertEqual(cookies[0], ('Set-Cookie', 'foo="bar"; Secure'))
+        self.assertEqual(cookies[0], ('Set-Cookie', 'foo=bar; Secure'))
 
     def test_setCookie_w_secure_false_value(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', secure='')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('secure'), '')
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertIsNone(cookie.get('Secure'))
 
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
-        self.assertEqual(cookies[0], ('Set-Cookie', 'foo="bar"'))
+        self.assertEqual(cookies[0], ('Set-Cookie', 'foo=bar'))
 
     def test_setCookie_w_httponly_true_value(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', http_only=True)
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('http_only'), True)
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertEqual(cookie.get('HttpOnly'), True)
 
         cookie_list = response._cookie_list()
         self.assertEqual(len(cookie_list), 1)
-        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo="bar"; HTTPOnly'))
+        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo=bar; HttpOnly'))
 
     def test_setCookie_w_httponly_false_value(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', http_only=False)
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('http_only'), False)
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertIsNone(cookie.get('HttpOnly'))
 
         cookie_list = response._cookie_list()
         self.assertEqual(len(cookie_list), 1)
-        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo="bar"'))
+        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo=bar'))
 
     def test_setCookie_w_same_site(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', same_site='Strict')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 3)
+        self.assertEqual(len(cookie), 2)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('same_site'), 'Strict')
-        self.assertEqual(cookie.get('quoted'), True)
+        self.assertEqual(cookie.get('SameSite'), 'Strict')
         cookies = response._cookie_list()
         self.assertEqual(len(cookies), 1)
         self.assertEqual(cookies[0],
-                         ('Set-Cookie', 'foo="bar"; SameSite=Strict'))
+                         ('Set-Cookie', 'foo=bar; SameSite=Strict'))
 
     def test_setCookie_unquoted(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar', quoted=False)
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 2)
+        self.assertEqual(len(cookie), 1)
         self.assertEqual(cookie.get('value'), 'bar')
-        self.assertEqual(cookie.get('quoted'), False)
 
         cookie_list = response._cookie_list()
         self.assertEqual(len(cookie_list), 1)
@@ -343,23 +330,23 @@ class HTTPResponseTests(unittest.TestCase):
         response = self._makeOne()
         response.setCookie('foo', b'bar')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 2)
+        self.assertEqual(len(cookie), 1)
         self.assertEqual(cookie.get('value'), b'bar')
 
         cookie_list = response._cookie_list()
         self.assertEqual(len(cookie_list), 1)
-        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo="bar"'))
+        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo=bar'))
 
     def test_setCookie_handle_unicode_values(self):
         response = self._makeOne()
         response.setCookie('foo', 'bar')
         cookie = response.cookies.get('foo', None)
-        self.assertEqual(len(cookie), 2)
+        self.assertEqual(len(cookie), 1)
         self.assertEqual(cookie.get('value'), 'bar')
 
         cookie_list = response._cookie_list()
         self.assertEqual(len(cookie_list), 1)
-        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo="bar"'))
+        self.assertEqual(cookie_list[0], ('Set-Cookie', 'foo=bar'))
 
     def test_appendCookie_w_existing(self):
         response = self._makeOne()
@@ -368,7 +355,7 @@ class HTTPResponseTests(unittest.TestCase):
         cookie = response.cookies.get('foo', None)
         self.assertTrue(cookie)
         self.assertEqual(cookie.get('value'), 'bar:baz')
-        self.assertEqual(cookie.get('path'), '/')
+        self.assertEqual(cookie.get('Path'), '/')
 
     def test_appendCookie_no_existing(self):
         response = self._makeOne()
@@ -382,23 +369,22 @@ class HTTPResponseTests(unittest.TestCase):
         response.expireCookie('foo', path='/')
         cookie = response.cookies.get('foo', None)
         self.assertTrue(cookie)
-        self.assertEqual(cookie.get('expires'),
+        self.assertEqual(cookie.get('Expires'),
                          'Wed, 31 Dec 1997 23:59:59 GMT')
-        self.assertEqual(cookie.get('max_age'), 0)
-        self.assertEqual(cookie.get('path'), '/')
+        self.assertEqual(cookie.get('Max-Age'), '0')
+        self.assertEqual(cookie.get('Path'), '/')
 
     def test_expireCookie1160(self):
         # Verify that the cookie is expired even if an expires kw arg is passed
-        # http://zope.org/Collectors/Zope/1160
         response = self._makeOne()
         response.expireCookie('foo', path='/',
                               expires='Mon, 22 Mar 2004 17:59 GMT', max_age=99)
         cookie = response.cookies.get('foo', None)
         self.assertTrue(cookie)
-        self.assertEqual(cookie.get('expires'),
+        self.assertEqual(cookie.get('Expires'),
                          'Wed, 31 Dec 1997 23:59:59 GMT')
-        self.assertEqual(cookie.get('max_age'), 0)
-        self.assertEqual(cookie.get('path'), '/')
+        self.assertEqual(cookie.get('Max-Age'), '0')
+        self.assertEqual(cookie.get('Path'), '/')
 
     def test_getHeader_nonesuch(self):
         response = self._makeOne()
@@ -646,6 +632,44 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(response.getHeader('Content-Length'),
                          str(len(ENCODED)))
 
+    def test_setBody_list(self):
+        """Test that setBody casts lists of ints into their str representation,
+        regardless of if the values are in byte range."""
+        resp = self._makeOne()
+        for body in ([1, 2, 3], [1, 2, 500]):
+            resp.setBody(body)
+            self.assertEqual(resp.body, str(body).encode('ascii'))
+
+    def test_setBody_io(self):
+        """
+        Test that BytesIO.getbuffer() can be used to write a binary response.
+        """
+        from io import BytesIO
+        resp = self._makeOne()
+        value = b'\x00\x01'
+        bio = BytesIO(value)
+        resp.setBody(bio.getbuffer())
+        self.assertEqual(resp.body, value)
+
+    def test_setBody_by_content_type(self):
+        """
+        Check that a list as response is treated differently depending on the
+        content type.
+        """
+        resp = self._makeOne()
+        body = [1, 2, 3]
+
+        resp.setBody(body)
+        self.assertEqual(resp.body, str(body).encode('ascii'))
+
+        resp.setHeader('Content-Type', 'application/x-octet-stream')
+        resp.setBody(body)
+        self.assertEqual(resp.body, bytes(body))
+
+        resp.setHeader('Content-Type', 'text/plain')
+        resp.setBody(body)
+        self.assertEqual(resp.body, str(body).encode('ascii'))
+
     def test_setBody_w_bogus_pseudo_HTML(self):
         # The 2001 checkin message which added the path-under-test says:
         # (r19315): "merged content type on error fixes from 2.3
@@ -776,6 +800,11 @@ class HTTPResponseTests(unittest.TestCase):
         exc = HTTPMovedPermanently(BYTES_URL)
         self._redirectURLCheck(exc, expected=ENC_URL)
 
+    def test_redirect_nonascii_everywhere(self):
+        URL = "http://uä:pä@sä:80/pä?qä#fä"
+        ENC_URL = "http://u%C3%A4:p%C3%A4@s%C3%A4:80/p%C3%A4?q%C3%A4#f%C3%A4"
+        self._redirectURLCheck(URL, ENC_URL)
+
     def test_redirect_alreadyquoted(self):
         # If a URL is already quoted, don't double up on the quoting
         ENC_URL = 'http://example.com/M%C3%A4H'
@@ -937,7 +966,7 @@ class HTTPResponseTests(unittest.TestCase):
         response._unauthorized()
         self.assertTrue('WWW-Authenticate' in response.headers)  # literal
         self.assertEqual(response.headers['WWW-Authenticate'],
-                         'basic realm="Zope"')
+                         'basic realm="Zope", charset="UTF-8"')
 
     def test__unauthorized_w_realm(self):
         response = self._makeOne()
@@ -945,7 +974,7 @@ class HTTPResponseTests(unittest.TestCase):
         response._unauthorized()
         self.assertTrue('WWW-Authenticate' in response.headers)  # literal
         self.assertEqual(response.headers['WWW-Authenticate'],
-                         'basic realm="Folly"')
+                         'basic realm="Folly", charset="UTF-8"')
 
     def test_unauthorized_no_debug_mode(self):
         response = self._makeOne()
@@ -986,7 +1015,7 @@ class HTTPResponseTests(unittest.TestCase):
         status, headers = response.finalize()
         self.assertEqual(status, '200 OK')
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('Content-Length', '0'),
                           ])
@@ -997,7 +1026,7 @@ class HTTPResponseTests(unittest.TestCase):
         status, headers = response.finalize()
         self.assertEqual(status, '200 OK')
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('Content-Length', '4'),
                           ])
@@ -1008,7 +1037,7 @@ class HTTPResponseTests(unittest.TestCase):
         status, headers = response.finalize()
         self.assertEqual(status, '200 OK')
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('Content-Length', '42'),
                           ])
@@ -1019,7 +1048,7 @@ class HTTPResponseTests(unittest.TestCase):
         status, headers = response.finalize()
         self.assertEqual(status, '200 OK')
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('Transfer-Encoding', 'slurry'),
                           ])
@@ -1030,7 +1059,7 @@ class HTTPResponseTests(unittest.TestCase):
         status, headers = response.finalize()
         self.assertEqual(status, '302 Found')
         expected = {
-            ('X-Powered-By', 'Zope (www.zope.org), Python (www.python.org)'),
+            ('X-Powered-By', 'Zope (www.zope.dev), Python (www.python.org)'),
             ('Content-Length', '0'),
             ('Location', 'http://example.com/'),
         }
@@ -1040,7 +1069,7 @@ class HTTPResponseTests(unittest.TestCase):
         response = self._makeOne()
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ])
 
@@ -1050,7 +1079,7 @@ class HTTPResponseTests(unittest.TestCase):
         response._wrote = True
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ])
 
@@ -1059,7 +1088,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.setHeader('Content-Length', 42)
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('Content-Length', '42'),
                           ])
@@ -1070,7 +1099,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.setHeader('Transfer-Encoding', 'slurry')
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('Transfer-Encoding', 'slurry'),
                           ])
@@ -1080,7 +1109,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.setHeader('x-consistency', 'Foolish')
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('X-Consistency', 'Foolish'),
                           ])
@@ -1090,7 +1119,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.setHeader('X-consistency', 'Foolish', literal=True)
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('X-consistency', 'Foolish'),
                           ])
@@ -1100,7 +1129,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.redirect('http://example.com/')
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('Location', 'http://example.com/'),
                           ])
@@ -1111,9 +1140,9 @@ class HTTPResponseTests(unittest.TestCase):
         response.appendCookie('foo', 'baz')
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
-                          ('Set-Cookie', 'foo="bar%3Abaz"; Path=/'),
+                          ('Set-Cookie', 'foo=bar%3Abaz; Path=/'),
                           ])
 
     def test_listHeaders_after_expireCookie(self):
@@ -1123,12 +1152,12 @@ class HTTPResponseTests(unittest.TestCase):
         cookie_header = headers.pop('Set-Cookie')
         headers = list(headers.items())
         expected = {
-            ('X-Powered-By', 'Zope (www.zope.org), Python (www.python.org)'),
+            ('X-Powered-By', 'Zope (www.zope.dev), Python (www.python.org)'),
         }
         self.assertEqual(set(headers), expected)
         self.assertEqual(
             set(cookie_header.split('; ')),
-            {'qux="deleted"', 'Path=/', 'Max-Age=0',
+            {'qux=deleted', 'Path=/', 'Max-Age=0',
              'Expires=Wed, 31 Dec 1997 23:59:59 GMT'}
         )
 
@@ -1138,7 +1167,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.addHeader('X-Consistency', 'Oatmeal')
         headers = response.listHeaders()
         self.assertEqual(headers,
-                         [('X-Powered-By', 'Zope (www.zope.org), '
+                         [('X-Powered-By', 'Zope (www.zope.dev), '
                                            'Python (www.python.org)'),
                           ('X-Consistency', 'Foolish'),
                           ('X-Consistency', 'Oatmeal'),
@@ -1149,7 +1178,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.setBody(b'BLAH')
         headers = response.listHeaders()
         expected = {
-            ('X-Powered-By', 'Zope (www.zope.org), Python (www.python.org)'),
+            ('X-Powered-By', 'Zope (www.zope.dev), Python (www.python.org)'),
             ('Content-Length', '4'),
             ('Content-Type', 'text/plain; charset=utf-8'),
         }
@@ -1167,7 +1196,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 5)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
             b'',
         }
@@ -1183,7 +1212,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 5)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 42',
             b'',
         }
@@ -1198,7 +1227,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 5)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Transfer-Encoding: slurry',
             b'',
         }
@@ -1212,7 +1241,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 6)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
             b'X-Consistency: Foolish',
             b'',
@@ -1227,7 +1256,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 6)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
             b'X-consistency: Foolish',
             b'',
@@ -1242,7 +1271,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 6)
         expected = {
             b'Status: 302 Found',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
             b'Location: http://example.com/',
             b'',
@@ -1258,9 +1287,9 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 6)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
-            b'Set-Cookie: foo="bar%3Abaz"; Path=/',
+            b'Set-Cookie: foo=bar%3Abaz; Path=/',
             b'',
         }
         self.assertEqual(set(lines), expected)
@@ -1275,7 +1304,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 6)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
             b'',
         }
@@ -1283,7 +1312,7 @@ class HTTPResponseTests(unittest.TestCase):
         cookie_value = cookie_line.split(b': ', 1)[-1]
         self.assertEqual(
             set(cookie_value.split(b'; ')),
-            {b'qux="deleted"', b'Path=/', b'Max-Age=0',
+            {b'qux=deleted', b'Path=/', b'Max-Age=0',
              b'Expires=Wed, 31 Dec 1997 23:59:59 GMT'}
         )
 
@@ -1296,7 +1325,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 7)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
             b'X-Consistency: Foolish',
             b'X-Consistency: Oatmeal',
@@ -1312,7 +1341,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 6)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 4',
             b'Content-Type: text/plain; charset=utf-8',
             b'BLAH',
@@ -1332,7 +1361,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(len(lines), 5)
         expected = {
             b'Status: 200 OK',
-            b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
+            b'X-Powered-By: Zope (www.zope.dev), Python (www.python.org)',
             b'Content-Length: 0',
             b'Kilroy was here!',
             b'',
@@ -1462,7 +1491,8 @@ class TestHeaderEncodingRegistry(unittest.TestCase):
                          1)
 
     def test_encode_words(self):
-        self.assertEqual(encode_words("ä"), "=?utf-8?b?w6Q=?=")
+        self.assertIn(encode_words("ä"),
+                      ("=?utf-8?b?w6Q=?=", "=?utf-8?q?=C3=A4?="))
 
     def test_encode_params(self):
         self.assertEqual(encode_params('abc; p1=1; p2="2"; p3="€"; p4=€; '
